==> minghu6-1.5.4rc1.tar.gz: minghu6-1.5.4rc1/minghu6/http/urlretrieve.py <==
# -*- coding:utf-8 -*-
# !/usr/bin/env python3

"""
################################################################################
About :urlretrieve ... download
################################################################################
"""
import sys

from minghu6.text.color import color

__all__ = ['report',
           'get_progress_bar',
           'report_color']


def report(count, block_size, total_size):
    """

    :param count:
    :param block_size:
    :param total_size:
    :return:
    """

    download_size = count * block_size
    percent = int(download_size * 100 / total_size)
    sys.stdout.write(('\rdownload ...{0:d}%'
                      '\t\t{1:f} Mb').format(percent, download_size / 10e5))
    sys.stdout.flush()




plus = '█'


def get_progress_bar(now_size, total_size, max_length=25, extra_str=''):
    """

    :param now_size:
    :param total_size:
    :param max_length:
    :return:
    """
    now_length = int(now_size * max_length / total_size)

    progress = plus * now_length + (max_length - now_length) * 2 * ' ' + extra_str

    progress_bar = progress

    return progress_bar


def report_color(count, block_size, total_size):
    download_size = count * block_size
    percent = (download_size * 100 / total_size)

    pts = ('\rdownload ...'
           '\t{0:.3f} mb ').format(download_size / 10e5)
    pts2 = get_progress_bar(download_size, total_size,
                            extra_str='{0:.2f}%'.format(percent))

    pts = ''.join([pts, pts2])
    sys.stdout.flush()
    color.print_info(pts, end='', flush=True)


if __name__ == '__main__':

    for i in range(10):
        report_color(5, 10, 100)

==> minghu6-1.6.1.tar.gz: minghu6-1.6.1/minghu6/http/urlretrieve.py <==
# -*- coding:utf-8 -*-
# !/usr/bin/env python3

"""
################################################################################
About :urlretrieve ... download
################################################################################
"""
import sys

from color import color

__all__ = ['report',
           'get_progress_bar',
           'report_color']


def report(count, block_size, total_size):
    """

    :param count:
    :param block_size:
    :param total_size:
    :return:
    """

    download_size = count * block_size
    percent = int(download_size * 100 / total_size)
    sys.stdout.write(('\rdownload ...{0:d}%'
                      '\t\t{1:f} Mb').format(percent, download_size / 10e5))
    sys.stdout.flush()




plus = '█'


def get_progress_bar(now_size, total_size, max_length=25, extra_str=''):
    """

    :param now_size:
    :param total_size:
    :param max_length:
    :return:
    """
    now_length = int(now_size * max_length / total_size)

    progress = plus * now_length + (max_length - now_length) * 2 * ' ' + extra_str

    progress_bar = progress

    return progress_bar


def report_color(count, block_size, total_size):
    download_size = count * block_size
    percent = (download_size * 100 / total_size)

    pts = ('\rdownload ...'
           '\t{0:.3f} mb ').format(download_size / 10e5)
    pts2 = get_progress_bar(download_size, total_size,
                            extra_str='{0:.2f}%'.format(percent))

    pts = ''.join([pts, pts2])
    sys.stdout.flush()
    color.print_info(pts, end='', flush=True)


if __name__ == '__main__':

    for i in range(10):
        report_color(5, 10, 100)
